<template>
    <main>
        <Header :page="page" />
        <div class="wrapper main">
            <div class="main__left main__left_hidden" v-if="$root.user === null">
                <aside class="user-side">
                    <div class="user-side__auth">
                        <Auth />
                    </div>
                </aside>
            </div>
            <div class="main__left main__left_hidden" v-else>
                <div class="user__bonus" @click="$root.goToBonus" style="display: none">
                    Бесплатный бонус <i class="fa fa-arrow-right" aria-hidden="true"></i>
                </div>
                <div class="user__info user__body">
                    <span class="user__initials">{{ $root.user.login.substr(0, 2) }}</span>
                    <div class="user__profile">
                        <span class="user__name">
                            {{ $root.user.login }}
                            <i class="fa fa-cog" aria-hidden="true" @click="$root.$emit('openSettings')"></i>
                        </span>
                        <span class="user__balance">
                            <IOdometer
                                class="IOdometer"
                                :value="$root.user.balance"
                                format="(ddd).dd"
                            />
                        </span>
                    </div>
                </div>
                <Finance />
                <Chat />
            </div>
            <div class="main__right">
                <router-view />
            </div>
        </div>
        <Footer />
        <notifications position="top-right"></notifications>
    </main>
</template>

<script>
import Header from '../components/Header.vue'
import Auth from '../components/Auth.vue'
import Finance from '../components/Finance.vue'
import Footer from '../components/Footer.vue'
import Chat from '../components/Chat.vue'
import Profile from "../components/modals/Profile"
import IOdometer from 'vue-odometer'
import "odometer/themes/odometer-theme-default.css"

export default {
    components: {
        Header,
        Auth,
        Finance,
        Footer,
        Chat,
        IOdometer,
        Profile
    },
    data() {
        return {
            page: null,
        }
    },
    mounted() {
        let error = document.getElementsByClassName('errors')[0].innerText;
        if(error.length > 0) notify({
            theme: 'red',
            text: error
        })

        this.$root.$on('showProfile', id => {
            this.$modal.show(
                Profile,
                {
                    id: id
                },
                {
                    width: "540px",
                    height: "auto",
                    adaptive: true,
                    resizable: false,
                    draggable: false,
                }
            );
        })

        this.$root.$on('openSettings', () => {
            this.$router.push({name: 'settings'})
        })
    },
    beforeMount() {
        this.page = this.$router.currentRoute.name;
    },
    beforeUpdate() {
        this.page = this.$router.currentRoute.name;
    },
    sockets: {
        transfer: function (data) {
            if(this.$root.user === null) return;

            if(this.$root.user.id == data.user_id) {
                this.$root.user.balance += Number(data.amount)
                notify({
                    theme: 'green',
                    text: `Вам перевели ${parseFloat(data.amount)} руб`
                })
            }
        }
    }
}
</script>
